The olr function runs all the possible combinations of linear regressions with all of the
dependent variables against the independent variable and returns the statistical summary
of either the greatest adjusted R-squared or R-squared term.
